==> org.opennms.features.flows.elastic-24.0.0-20181221.195855-58-sources.jar: org/opennms/netmgt/flows/elastic/PersistenceException.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.flows.elastic;

import java.util.ArrayList;
import java.util.List;

import org.opennms.netmgt.flows.api.FlowException;
import org.opennms.plugins.elasticsearch.rest.bulk.FailedItem;

public class PersistenceException extends FlowException {

    private List<FailedItem<FlowDocument>> failedItems = new ArrayList<>();

    public PersistenceException(String message, List<FailedItem<FlowDocument>> failedItems) {
        super(message);
        this.failedItems = failedItems;
    }

    public List<FailedItem<FlowDocument>> getFailedItems() {
        return failedItems;
    }
}

==> org.opennms.features.flows.elastic-25.0.0-20200620.164956-224-sources.jar: org/opennms/netmgt/flows/elastic/PersistenceException.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.flows.elastic;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import org.opennms.netmgt.flows.api.DetailedFlowException;
import org.opennms.features.jest.client.bulk.FailedItem;

public class PersistenceException extends DetailedFlowException {

    private List<FailedItem<FlowDocument>> failedItems = new ArrayList<>();

    public PersistenceException(String message, List<FailedItem<FlowDocument>> failedItems) {
        super(message);
        this.failedItems = failedItems;
    }

    public List<FailedItem<FlowDocument>> getFailedItems() {
        return failedItems;
    }

    @Override
    public List<String> getDetailedLogMessages() {
        return getFailedItems().stream()
                .map(e -> String.format("Failed to persist item with convoKey '%s' and index %d: %s", e.getItem().getConvoKey(), e.getIndex(), e.getCause().getMessage())).collect(Collectors.toList());
    }
}
